.. _swh-graph:

.. include:: README.rst


.. toctree::
   :maxdepth: 1
   :caption: Overview

   quickstart
   api
   grpc-api
   Rust API <https://docs.rs/swh-graph/>
   memory
   compression
   cli
   docker
   git2graph
   testing
   example-dataset
   provenance-index

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
